@@ -1546,10 +1546,35 @@ class SimbaSync:
         code: str,
         app_name=None,
         args=None,
+        encode: bool = True,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> Tuple[str, str]:
+        """
+        POST ``/v2/organisations/{organisation}/deployments/library/``
 
+        Deploy a library and wait for completion.
+        This results in a deployment object being created and returned.
+
+        :param org: The organisation to deploy to.
+        :type org: str
+        :param code: The library code.
+        :type code: str
+        :param lib_name: The name of the library.
+        :type lib_name: str
+        :param blockchain: The name of the blockchain to deploy to.
+        :type blockchain: str
+        :param encode: whether to base64 encode the code or not.
+        :type encode: bool
+
+        :Keyword Arguments:
+            * **app_name** (`str`) - App name for the library.
+            * **args** (`dict`) - Constructor args for the deployment.
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: A tuple of address and contract ID
+        :rtype: Tuple[str, str]
+        """
         res = self.deploy_library(
             org=org,
             lib_name=lib_name,
@@ -1557,6 +1582,7 @@ class SimbaSync:
             code=code,
             args=args,
             app_name=app_name,
+            encode=encode,
             login=login,
             config=config
         )
@@ -1581,6 +1607,8 @@ class SimbaSync:
         storage: Optional[str] = "no_storage",
         display_name: str = None,
         args: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
     ) -> Tuple[str, str]:
         """
         POST ``/v2/organisations/{organisation}/contract_designs/deploy/``
@@ -1617,6 +1645,8 @@ class SimbaSync:
             storage=storage,
             args=args,
             display_name=display_name,
+            login=login,
+            config=config
         )
         deployment_id = res["deployment_id"]
         try:
@@ -1639,6 +1669,8 @@ class SimbaSync:
         storage: Optional[str] = "no_storage",
         display_name: str = None,
         args: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
     ) -> Tuple[str, str]:
         """
         POST ``/v2/organisations/{organisation}/contract_artifacts/``
@@ -1675,6 +1707,8 @@ class SimbaSync:
             storage=storage,
             args=args,
             display_name=display_name,
+            login=login,
+            config=config
         )
         deployment_id = res["id"]
         try:
@@ -1852,7 +1886,7 @@ class SimbaSync:
         config: ConnectionConfig = None,
     ) -> dict:
         """
-        GET ``/services/contracts/abi/{contract_address}/``
+        GET ``/services/blockchains/{blockchain}/contracts/{contract_address}/abi/``
 
         Get the ABI and metadata for a contract address.
 
@@ -1890,8 +1924,8 @@ class SimbaSync:
             * **alias** (`Optional[str]`)
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
-        :return: a Dict with keys `abi` and `metadata`.
-        :rtype: dict
+        :return: a list of account objects
+        :rtype: list
         """
         params = None
         if nickname or alias:
@@ -1921,7 +1955,7 @@ class SimbaSync:
         :Keyword Arguments:
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
-        :return: a Dict with keys `abi` and `metadata`.
+        :return: an account object.
         :rtype: dict
         """
         return SimbaRequest(
@@ -1944,10 +1978,19 @@ class SimbaSync:
 
         Create a new account for the current user.
 
+        :param network_subtype: The blockchain subtype.
+        :type network_subtype: str
+        :param network: The blockchain name.
+        :type network: str
+        :param nickname: The account nickname.
+        :type nickname: str
+        :param alias: The account alias.
+        :type alias: str
+
         :Keyword Arguments:
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
-        :return: a Dict with keys `abi` and `metadata`.
+        :return: an account object.
         :rtype: dict
         """
         payload = {
@@ -1980,10 +2023,24 @@ class SimbaSync:
 
         Create a new account for the current user.
 
+        :param network_subtype: The blockchain subtype.
+        :type network_subtype: str
+        :param network: The blockchain name.
+        :type network: str
+        :param nickname: The account nickname.
+        :type nickname: str
+        :param alias: The account alias.
+        :type alias: str
+        :param address: The account address.
+        :type address: str
+        :param private_key: The account private key.
+        :type private_key: str
+
         :Keyword Arguments:
+            * **network_type** (`Optional[str]`)
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
-        :return: a Dict with keys `abi` and `metadata`.
+        :return: an account object.
         :rtype: dict
         """
         payload = {
@@ -2010,14 +2067,19 @@ class SimbaSync:
         config: ConnectionConfig = None,
     ) -> dict:
         """
-        POST ``/user/accounts/{id}``
+        POST ``/user/accounts/{account_id}/sign/``
 
-        Get the account for the current user to sign inputs.
+        Sign a message using the specified account.
+
+        :param uid: The account id.
+        :type uid: str
+        :param input_pairs: A list of tuples defining the data type and data to sign.
+        :type input_pairs: List[Tuple(str, Any)]
 
         :Keyword Arguments:
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
-        :return: a Dict with keys `abi` and `metadata`.
+        :return: a Dict with the signed content.
         :rtype: dict
         """
         payload = {
