@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 SIMBA Chain Inc. https://simbachain.com
+#  Copyright (c) 2024 SIMBA Chain Inc. https://simbachain.com
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -51,15 +51,20 @@ class Path(str, Enum):
     BUNDLE_FILE = "/v2/apps/{}/contract/{}/bundle/{}/filename/{}/"
     BUNDLE_MANIFEST = "/v2/apps/{}/contract/{}/bundle/{}/manifest/"
     CONTRACT_INFO = "/v2/apps/{}/contract/{}/info"
-    CONTRACT_EVENTS = "/v2/apps/{}/contract/{}/events/{}/"
+    CONTRACT_EVENTS = "/v2/apps/{}/contract/{}/events/"
     CONTRACT_RECEIPT = "/v2/apps/{}/contract/{}/receipt/{}/"
     CONTRACT_METHOD = "/v2/apps/{}/contract/{}/{}/"
+    CONTRACT_ABI = "/services/blockchains/{}/contracts/{}/abi/"
     SYNC_CONTRACT_METHOD = "/v2/apps/{}/sync/contract/{}/{}/"
     USER_FUND_ADDRESS = "/user/account/{}/fund/"
     USER_ADDRESS_BALANCE = "/user/account/{}/balance/{}/"
     ADMIN_WALLET_SET = "/admin/users/{}/wallet/set/"
     USER_WALLET_SET = "/user/wallet/set/"
     USER_WALLET = "/user/wallet/"
+    USER_ACCOUNTS = "/user/accounts/"
+    USER_ACCOUNT = "/user/accounts/{}/"
+    USER_ACCOUNT_SIGN = "/user/accounts/{}/sign/"
+    USER_ACCOUNT_SET = "/user/accounts/set/"
     ORGANISATION = "/v2/organisations/{}/"
     ORGANISATIONS = "/v2/organisations/"
     ORG_APP = "/v2/organisations/{}/applications/{}/"
@@ -75,12 +80,19 @@ class Path(str, Enum):
     DESIGN_DEPLOY = "/v2/organisations/{}/contract_designs/{}/deploy/"
     DEPLOYMENT = "/v2/organisations/{}/deployments/{}/"
     DEPLOYMENTS = "/v2/organisations/{}/deployments/"
+    LIBRARIES = "/v2/organisations/{}/deployments/library/"
     STORAGES = "/v2/organisations/{}/storage/"
     BLOCKCHAINS = "/v2/organisations/{}/blockchains/"
     SUBSCRIPTIONS = "/v2/organisations/{}/subscriptions/"
     SUBSCRIPTION = "/v2/organisations/{}/subscriptions/{}/"
     NOTIFICATION_CONFIGS = "/v2/organisations/{}/notification_config/"
 
+    def create(self, *args) -> str:
+        slots = self.value.count("{}")
+        if slots != len(args):
+            raise ValueError(f"Incorrect number of args ({len(args)}) supplied to {self.value}")
+        return self.value.format(*args)
+
 
 class RetryTransport(httpx.AsyncBaseTransport, httpx.BaseTransport):
 
@@ -266,6 +278,17 @@ def get_address(deployment: dict) -> Optional[str]:
     return deployment.get("primary", {}).get("address", None)
 
 
+def get_address_by_name(deployment, name):
+    deps = deployment.get("deployment", [])
+    primary = deployment.get("primary")
+    if primary and primary.get("name") == name:
+        return primary.get("address")
+    for dep in deps:
+        if dep.get("name") == name:
+            return dep.get("address")
+    return None
+
+
 def get_deployed_artifact_id(deployment: dict) -> Optional[str]:
     """
     Extract the primary deployed artifact ID from a deployment object.
@@ -274,4 +297,4 @@ def get_deployed_artifact_id(deployment: dict) -> Optional[str]:
     :type deployment: dict
     :return: Optional[str]
     """
-    return deployment.get("primary", {}).get("deployed_artifact_id", None)
\ No newline at end of file
+    return deployment.get("primary", {}).get("deployed_artifact_id", None)
